@@ -206,6 +206,8 @@ class OrcaJob:
         )
         header.append(line)
         header.append("")
+        header.append("%pal nprocs 4 end")
+        header.append("")
         logging.debug("Header: \n %s", "\n".join(header))
         return header
 
@@ -215,7 +217,9 @@ class OrcaJob:
 
         List of strings.
         """
-        block = ["* xyz " + str(self.molecule.charge) + " " + str(self.molecule.multiplicity)]
+        block = [
+            "* xyz " + str(self.molecule.charge) + " " + str(self.molecule.multiplicity)
+        ]
         block.extend(self.molecule.xyz_geometry())
         block.append("*")
         logging.debug("Geometry block: \n %s", "\n".join(block))
